.django-glue-message-list {

}

.django-glue-message-list-viewport {
    position: absolute;
    bottom: 0;
}

.django-glue-message {
    opacity: 1;
    transition: opacity 0.5s ease-in-out;
}

.django-glue-message-fade {
    opacity: 0;
}

.django-glue-message-success {
    background-color: #BEB;
}

.django-glue-message-info {
    background-color: #EEE;
}

.django-glue-message-warning {
    background-color: #EEB;
}

.django-glue-message-error {
    background-color: #EBB;
}